@@ -9,31 +9,38 @@ Fun::~Fun()
 }
 
 
-void Fun::Init(Graph *g0, double *par0, int *parn, int *gt, int *ft, double *fpar0, int *included0, int *dbg0)
+void Fun::Init(Graph *g0, double *par0, int *parn, int *gt, int *ft, double *fpar0, int *trans0, int *included0, int *dbg0)
 {
 	int i;
 	graph = g0;
 	std::vector<double> * pvec;
 	for(i=0;i<*parn;i++)
 	{
-		pvec = new std::vector<double>;
 		parvec.push_back(par0[i]);
+		pvec = new std::vector<double>;
 		value.push_back(*pvec);
 		value.at(i).push_back(0.0);
+		delete pvec;
 	}
 	included = included0;
 	gtype = gt;
 	ftype = ft;
 	fpar = fpar0;
 	dbg = dbg0;
+
+	trans = trans0;
+	if(*trans>0){
+		graph->pp->calcTransWeights();
+	}
 }
 
 
-SEXP Fun::toSEXP()
+SEXP Fun::toSEXP(SEXP pp)
 //transform a std::vector<double > to SEXP
 {
 	SEXP res, *onevalue;
-	double *p;
+	double *p, *m;
+
 	PROTECT(res = allocVector(VECSXP, this->value.size()));
 	int i,j;
 	for(i=0;i < (int)this->value.size();i++)
@@ -46,8 +53,13 @@ SEXP Fun::toSEXP()
 			p[j] = this->value.at(i).at(j);
 		SET_VECTOR_ELT(res, i, *onevalue);
 		UNPROTECT(1);
+		delete onevalue;
 	}
 	UNPROTECT(1);
+//	set the mass element of pp
+	m = REAL(getListElement(pp,"mass"));
+	for(int i=0; i< graph->pp->size();i++)
+		m[i] = graph->pp->getMass2(&i);
 	return res;
 }
 
@@ -77,7 +89,9 @@ void Fun::calculate()
 			resvec = isar(graph, fpar, dbg, included);
 		if(*ftype == 5)
 			resvec = mci(graph, fpar, dbg, included);
-		value.at(i) = resvec;
+		if(*ftype == 6)
+			resvec = biomass(graph, fpar, dbg, included);
+				value.at(i) = resvec;
 		if(*this->dbg)printf(" ]\n");
 	}
 }
